@@ -1,4 +1,22 @@
-/* $Id: register.c 299 2002-02-06 21:40:00Z wojtekka $ */
+/* $Id$ */
+
+/*
+ *  (C) Copyright 2001-2006 Wojtek Kaniewski <wojtekka@irc.pl>
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU Lesser General Public License Version
+ *  2.1 as published by the Free Software Foundation.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU Lesser General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307,
+ *  USA.
+ */
 
 #include <stdio.h>
 #include <string.h>
@@ -6,16 +24,22 @@
 
 #ifdef ASYNC
 
-#include <sys/select.h>
-#include <sys/wait.h>
+#ifdef _WIN32
+#  include <winsock2.h>
+#else
+#  include <sys/select.h>
+#  include <sys/wait.h>
+#endif
 #include <signal.h>
 #include <errno.h>
 
+#ifndef _WIN32
 static void sigchld(int sig)
 {
 	wait(NULL);
 	signal(SIGCHLD, sigchld);
 }
+#endif
 
 #endif
 
@@ -39,7 +63,7 @@ int main(int argc, char **argv)
 	tokenval = argv[4];
 
 	gg_debug_level = 255;
-	
+
 #ifndef ASYNC
 	if (!(h = gg_register3(email, password, tokenid, tokenval, 0))) {
 		printf("Błąd rejestracji.\n");
@@ -48,25 +72,27 @@ int main(int argc, char **argv)
 
 #else
 
+#ifndef _WIN32
 	signal(SIGCHLD, sigchld);
+#endif
 
 	if (!(h = gg_register3(email, password, tokenid, tokenval, 1)))
 		return 1;
 
-        while (1) {
-                fd_set rd, wr, ex;
+	while (1) {
+		fd_set rd, wr, ex;
 
-                FD_ZERO(&rd);
-                FD_ZERO(&wr);
-                FD_ZERO(&ex);
+		FD_ZERO(&rd);
+		FD_ZERO(&wr);
+		FD_ZERO(&ex);
 
-                if ((h->check & GG_CHECK_READ))
-                        FD_SET(h->fd, &rd);
-                if ((h->check & GG_CHECK_WRITE))
-                        FD_SET(h->fd, &wr);
-                FD_SET(h->fd, &ex);
+		if ((h->check & GG_CHECK_READ))
+			FD_SET(h->fd, &rd);
+		if ((h->check & GG_CHECK_WRITE))
+			FD_SET(h->fd, &wr);
+		FD_SET(h->fd, &ex);
 
-                if (select(h->fd + 1, &rd, &wr, &ex, NULL) == -1 || FD_ISSET(h->fd, &ex)) {
+		if (select(h->fd + 1, &rd, &wr, &ex, NULL) == -1 || FD_ISSET(h->fd, &ex)) {
 			if (errno == EINTR)
 				continue;
 			gg_free_register(h);
@@ -74,7 +100,7 @@ int main(int argc, char **argv)
 			return 1;
 		}
 
-                if (FD_ISSET(h->fd, &rd) || FD_ISSET(h->fd, &wr)) {
+		if (FD_ISSET(h->fd, &rd) || FD_ISSET(h->fd, &wr)) {
 			if (gg_register_watch_fd(h) == -1) {
 				gg_free_register(h);
 				fprintf(stderr, "Błąd połączenia.\n");
@@ -88,7 +114,7 @@ int main(int argc, char **argv)
 			if (h->state == GG_STATE_DONE)
 				break;
 		}
-        }
+	}
 #endif
 
 	p = h->data;
@@ -97,4 +123,3 @@ int main(int argc, char **argv)
 
 	return 0;
 }
-
